@@ -35,6 +35,10 @@ from drfp import DrfpEncoder
     default=False,
     help="Whether or not to also export a mapping to help interpret the fingerprint.",
 )
+@click.option("--hydrogens", is_flag=True, help="Include hydrogens explicitly.")
+@click.option(
+    "--root", is_flag=True, help="Root central atoms during substructure generation."
+)
 @click.option(
     "--silent", is_flag=True, help="Hide all output such as the progress bar."
 )
@@ -44,9 +48,11 @@ def main(
     n_folded_length: int,
     min_radius: int,
     radius: int,
-    rings: True,
-    mapping: False,
-    silent: False,
+    rings: bool = True,
+    mapping: bool = False,
+    hydrogens: bool = False,
+    root: bool = False,
+    silent: bool = False,
 ):
     """Creates fingerprints from a file containing one reaction SMILES per line.
 
@@ -71,7 +77,9 @@ def main(
             radius,
             rings,
             mapping,
+            root_central_atom=root,
             show_progress_bar=show_progress_bar,
+            include_hydrogens=hydrogens,
         )
     else:
         fps = DrfpEncoder.encode(
@@ -81,7 +89,9 @@ def main(
             radius,
             rings,
             mapping,
+            root_central_atom=root,
             show_progress_bar=show_progress_bar,
+            include_hydrogens=hydrogens,
         )
 
     pickle.dump(fps, output_file)
